@@ -770,6 +770,13 @@ def test_plan_handle_get(mocker, plan_json, config, response, monkeypatch):
     )
     tuxsuite.cli.main()
 
+    # Test failure case when the response is 404
+    response.status_code = 404
+    get_req = mocker.patch("requests.get", return_value=response)
+    with pytest.raises(SystemExit) as exit:
+        tuxsuite.cli.main()
+    assert exit.value.code == 1
+
 
 def test_plan_handle_cancel(mocker, plan_json, config, response, monkeypatch):
     monkeypatch.setattr(
