@@ -551,7 +551,7 @@ class Plan(HeadersMixin):
         self.plan_type.create_builds(self, builds)
 
         # Create the tests
-        for (build, cfg) in zip(builds, self.config.plan):
+        for build, cfg in zip(builds, self.config.plan):
             if build:
                 for test in cfg["tests"]:
                     tests.append(
@@ -603,7 +603,7 @@ class Plan(HeadersMixin):
                 self.headers,
                 [t.generate_test_request(plan=self.plan) for t in tests],
             )
-            for (test, data) in zip(tests, ret):
+            for test, data in zip(tests, ret):
                 test.uid = data["uid"]
                 test.status = data
                 self.tests.append(test)
@@ -678,7 +678,7 @@ class Plan(HeadersMixin):
 
     def load(self, data):
         # builds --> kernel or bake
-        for (uid, b) in data["builds"].items():
+        for uid, b in data["builds"].items():
             if "build_name" in b:
                 build = self.load_kernel_builds(b)
                 self.builds.append(build)
@@ -687,7 +687,7 @@ class Plan(HeadersMixin):
                 self.builds.append(oebuild)
 
         # tests
-        for (uid, t) in data["tests"].items():
+        for uid, t in data["tests"].items():
             test = Test(
                 device=t["device"],
                 token=self.token,
