@@ -2,10 +2,11 @@
 
 import argparse
 import tuxsuite
+import tuxsuite.exceptions
 import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Test
-from tuxsuite.cli.requests import apiurl, get
+from tuxsuite.cli.requests import apiurl, get, post
 from tuxsuite.cli.utils import (
     LIMIT,
     datediff,
@@ -74,6 +75,10 @@ def handle_get(options, _, config):
                 icon = icons.ERROR
             elif test.result == "fail":
                 icon = icons.FAIL
+            elif test.result == "canceled":
+                icon = icons.CANCELED
+            elif test.result == "unknown":
+                icon = icons.UNKNOWN
             print(f"{icon} time : {test.finished_time}")
         if test.duration:
             print(f"duration: {test.duration}")
@@ -84,10 +89,26 @@ def handle_get(options, _, config):
             color = colors.green
         elif test.result in ["error", "fail"]:
             color = colors.red
+        elif test.result == "canceled":
+            color = colors.white
+        elif test.result == "unknown":
+            color = colors.purple
         print(f"result  : {color}{test.result}{colors.reset}")
     return 0
 
 
+def handle_cancel(options, _, config):
+    url = f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}/cancel"
+    ret = post(config, url, data={})
+    print(f"canceling job for {options.uid}")
+
+    if ret.status_code != 200:
+        print(f"unable to cancel test {options.uid}")
+        raise tuxsuite.exceptions.URLNotFound()
+
+    return 0
+
+
 def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/tests"
     ret = get(config, url)
@@ -165,6 +186,10 @@ def handle_results(options, _, config):
                 print(f"{k1}.{k2}: {colors.green}{v2['result']}{colors.reset}")
             elif v2["result"] == "fail":
                 print(f"{k1}.{k2}: {colors.red}{v2['result']}{colors.reset}")
+            elif v2["result"] == "canceled":
+                print(f"{k1}.{k2}: {colors.white}{v2['result']}{colors.reset}")
+            elif v2["result"] == "unknown":
+                print(f"{k1}.{k2}: {colors.purple}{v2['result']}{colors.reset}")
             else:
                 print(f"{k1}.{k2}: {v2['result']}")
     return 0
@@ -216,6 +241,10 @@ def handle_wait(options, _, config):
         icon = icons.ERROR
     elif test.result == "fail":
         icon = icons.FAIL
+    elif test.result == "canceled":
+        icon = icons.CANCELED
+    elif test.result == "unknown":
+        icon = icons.UNKNOWN
     print(f"{icon} time : {test.finished_time}")
 
     if test.duration:
@@ -226,6 +255,10 @@ def handle_wait(options, _, config):
         color = colors.green
     elif test.result in ["error", "fail"]:
         color = colors.red
+    elif test.result == "canceled":
+        color = colors.white
+    elif test.result == "unknown":
+        color = colors.purple
     print(f"result  : {color}{test.result}{colors.reset}")
     return 0
 
@@ -294,7 +327,11 @@ def handle_submit(cmdargs, _, config):
     if cmdargs.no_wait:
         format_result(test.status, test.url)
     else:
-        test_result = wait_for_object(test)
+        try:
+            test_result = wait_for_object(test)
+        except tuxsuite.exceptions.Timeout as exc:
+            test_result = False
+            sys.stderr.write(f"Error: {str(exc)}\n")
 
     if cmdargs.json_out:
         cmdargs.json_out.write(json.dumps(test.status, sort_keys=True, indent=4))
@@ -311,6 +348,7 @@ handlers = {
     "results": handle_results,
     "submit": handle_submit,
     "wait": handle_wait,
+    "cancel": handle_cancel,
 }
 
 
@@ -442,8 +480,12 @@ def setup_parser(parser):
     t = parser.add_parser("submit")
     test_cmd_options(t)
 
-    # "test wait <uid>
+    # "test wait <uid>"
     t = parser.add_parser("wait")
     t.add_argument("uid")
 
+    # "test cancel <uid>"
+    t = parser.add_parser("cancel")
+    t.add_argument("uid")
+
     return sorted(parser._name_parser_map.keys())
